'use strict';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadJSON = void 0;
const types_1 = require("../types");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const constants_1 = require("../util/constants");
function loadJSON(codeType, machineType, variant) {
    const fname = `${codeType[0]}${constants_1.constants.jsonExt}`;
    switch (codeType) {
        case types_1.CodeTypes.G:
            {
                try {
                    const gFile = fs_1.default.readFileSync(path_1.default.join(__dirname, machineType, fname), { encoding: 'utf-8' });
                    const g = JSON.parse(gFile);
                    if (variant) {
                        const variantName = `${codeType[0]}.${variant}${constants_1.constants.jsonExt}`;
                        if (!fs_1.default.existsSync(path_1.default.join(__dirname, machineType, 'variants', variantName))) {
                            return g;
                        }
                        try {
                            const vFile = fs_1.default.readFileSync(path_1.default.join(__dirname, machineType, 'variants', variantName), 'utf-8');
                            const v = JSON.parse(vFile);
                            const newCodes = { ...g.codes, ...v.codes };
                            g.codes = newCodes;
                            v.variant.remove.forEach(c => {
                                delete g.codes[c];
                            });
                            return g;
                        }
                        catch (err) {
                            console.error(`Error loading ${variant} G-Code JSON File`);
                        }
                    }
                    return g;
                }
                catch (err) {
                    console.error(`Error loading JSON file ${fname}...`, err);
                }
            }
            break;
        case types_1.CodeTypes.M:
            {
                try {
                    const mFile = fs_1.default.readFileSync(path_1.default.join(__dirname, machineType, fname), { encoding: 'utf-8' });
                    const m = JSON.parse(mFile);
                    if (variant) {
                        const variantName = `${codeType[0]}.${variant}${constants_1.constants.jsonExt}`;
                        if (!fs_1.default.existsSync(path_1.default.join(__dirname, machineType, 'variants', variantName))) {
                            return m;
                        }
                        try {
                            const vFile = fs_1.default.readFileSync(path_1.default.join(__dirname, machineType, 'variants', variantName), 'utf-8');
                            const v = JSON.parse(vFile);
                            const newCodes = { ...m.codes, ...v.codes };
                            m.codes = newCodes;
                            v.variant.remove.forEach(c => {
                                delete m.codes[c];
                            });
                            return m;
                        }
                        catch (err) {
                            console.error(`Error loading ${variant} M-Code JSON File`);
                        }
                    }
                    return m;
                }
                catch (err) {
                    console.error(`Error loading JSON file ${fname}...`, err);
                }
            }
            break;
        default: {
            return undefined;
        }
    }
    return undefined;
}
exports.loadJSON = loadJSON;
//# sourceMappingURL=index.js.map