'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.HTMLUtils = void 0;
class HTMLUtils {
    static codeToHTML(title, code, partial = true) {
        const html = [];
        if (!partial) {
            html.push('<!DOCTYPE html>\n<html lang="en"');
            html.push('<head>\n<meta charset="utf-8">\n</head>');
        }
        html.push(`<h1>${title.toUpperCase()} - ${code.shortDesc}</h1>\n`);
        if (code.desc) {
            html.push('<h2>Description</h2>\n');
            html.push(`<p>${code.desc}</p>\n`);
        }
        if (code.modal) {
            html.push(`<h3>Modal: ${code.modal ? 'true' : 'false'}</h3>\n`);
        }
        if (code.parameters) {
            html.push('<h2>Parameters</h2>\n');
            html.push('<table>', '<thead>', '<tr>\n<th>Parameter</th>\n<th>Description</th>\n<th>Optional</th>\n</tr>', '</thead>');
            html.push('<tbody>');
            for (const p in code.parameters) {
                html.push('<tr>', `<td>${p}</td>`, `<td>${code.parameters[p].shortDesc}</td>`, `<td>${code.parameters[p].optional ? 'true' : 'false'}`, '</tr>');
            }
        }
        if (!partial) {
            html.push('</html>');
        }
        return html.join('\n');
    }
    static allCodesToHTML(codes, partial = true) {
        const html = [];
        if (!partial) {
            html.push('<!DOCTYPE html>\n<html lang="en"');
            html.push('<head>\n<meta charset="utf-8">\n</head>');
        }
        html.push(`<h1>${codes.title}</h1>`);
        html.push(`<p>${codes.description}</p>`);
        html.push('<hr />');
        for (const c in codes.codes) {
            html.push(HTMLUtils.codeToHTML(c, codes.codes[c]));
            html.push('<hr />');
        }
        if (!partial) {
            html.push('</html>');
        }
        return html.join('\n');
    }
}
exports.HTMLUtils = HTMLUtils;
//# sourceMappingURL=htmlUtils.js.map